<?php

// ------------------------------------------------------------------------------
// Output
// ------------------------------------------------------------------------------

$options = get_option('shareplus_options');


// ---------- request selected share+ theme's CSS
function shareplus_css() {

  $options = get_option('shareplus_options');
	$theme = $options['theme_select'];

    wp_register_style('shareplus', plugins_url('themes/default/style.css', dirname(__FILE__) ), array(), '2.1');
    wp_enqueue_style('shareplus');

    if($theme == "clean"){

      wp_enqueue_style('shareplus-clean', plugins_url('themes/clean/style.css', dirname(__FILE__) ), array('shareplus'), '1.0');

    } elseif($theme == "simple") {

      wp_enqueue_style('shareplus-simple', plugins_url('themes/simple/style.css', dirname(__FILE__) ), array('shareplus'), '1.0');

    } elseif($theme == "paper") {

      wp_enqueue_style('shareplus-paper', plugins_url('themes/paper/style.css', dirname(__FILE__) ), array('shareplus'), '1.0');

    } elseif($theme == "facebook") {

      wp_enqueue_style('shareplus-facebook', plugins_url('themes/facebook/style.css', dirname(__FILE__) ), array('shareplus'), '1.0');

    } elseif($theme == "squared") {

      wp_enqueue_style('shareplus-squared', plugins_url('themes/squared/style.css', dirname(__FILE__) ), array('shareplus'), '1.0');

    }

}
add_action('wp_enqueue_scripts', 'shareplus_css');


// ---------- Register my scripts
function register_scripts() {
	// Register the share+ script
	wp_register_script('shareplus', plugins_url( 'js/shareplus.min.js', dirname(__FILE__) ), array('jquery'), '4.1', true);

	// waypoints.js
	wp_register_script('waypoints', plugins_url( 'js/waypoints.min.js', dirname(__FILE__) ), array('jquery'), '2.0.0', true);
}
add_action('init', 'register_scripts'); // register, but don't include yet


function shareplus_load_scripts() {

    wp_enqueue_script('jquery'); // load jQuery

    wp_enqueue_script('shareplus'); // load share+

    $options = get_option('shareplus_options');
    if($options['auto_open'] == "onvisible" || $options['auto_open'] == "onvisible_delay"){
      wp_enqueue_script('waypoints'); // load only if needed
    }

}
add_action('wp_enqueue_scripts', 'shareplus_load_scripts'); // add the scripts if needed



// ---------- get list of icons to display
function get_icons(){
  // get the icon wanted
  $options = get_option('shareplus_options');

  $display_icons = array(); // array of icon that will be filled

  global $sites; // get all the sites

  foreach ($sites as $service) {
    $icon = $options[$service];
    if($icon == "1") {
      array_push($display_icons, $service);
    }
  }

  return implode(',', $display_icons); // return the results as a comma separated list
}



/* ================================================== [main output] ----------> */

function shareplus_settings() {

  $options = get_option('shareplus_options');

  // check if share+ is allowed to run on this page
  if(is_home() && $options['display_home'] !== "1" || is_single() && $options['display_posts'] !== "1" || is_page() && $options['display_pages'] !== "1" || is_archive() && $options['display_archives'] !== "1") {
    return false;
  }

  // save reused options to a variable
	$title = $options['share_box_title'];
	$auto_open = $options['auto_open'];


?>
<script type="text/javascript">
jQuery(document).ready(function(){
	jQuery('.shareplus').shareplus({
  	<?php if($title){ ?>
  	title: "<?php echo $title; ?>",
		<?php } else { ?>
		displayTitle: false,
		<?php } // end title ?>

		sharetitle: "<?php is_single() ? the_title() : wp_title(''); ?>",


		icons: "<?php echo get_icons(); ?>",

		targetBlank: <?php echo $options['new_tab'] == "yes" ? "true" : "false"; ?>,

		<?php if($options['fb_button'] == "1") { ?>
		fbAction: "<?php echo $options['fb_action']; ?>",
		fbcolorscheme: "<?php echo $options['fb_colour']; ?>",
		<?php } else { ?>
		fbLikebox: false,
		<?php } // end if fb_button ?>

		<?php if($options['tweet_button'] == "1") { ?>
		tweetText: jQuery(document).attr('title'),
		tweetVia: "<?php echo $options['tweet_via'] ? $options['tweet_via'] : "danielpaul94"; ?>",
		twitterRelated: "<?php echo $options['twitter_related']; ?>",
		<?php } else { ?>
		tweets: false,
		<?php } // end if twitter button ?>

		pin: <?php echo $options['pin_button'] == "1" ? "true" : "false"; ?>,
		gplus: <?php echo $options['gplus_button'] == "1" ? "true" : "false"; ?>,

		ga: <?php echo $options['ga'] == "1" ? "true" : "false"; ?>,

		sticker: <?php echo $options['sticky_button'] == "1" ? "true" : "false"; ?>,
		stickerAlign: '<?php echo $options['sticky_button_position']; ?>'
	});
	<?php if($auto_open == "onvisible"){ // when visible	?>
	   jQuery('#shareplus_scroll').waypoint(function(direction) {
	     jQuery('.shareplus').shareplus('open');
	   }, {
  	   triggerOnce: true,
  	   offset: 'bottom-in-view'
  	 });
  <?php } elseif($auto_open == "onvisible_delay") { // timeout after visible ?>
      jQuery('#shareplus_scroll').waypoint(function(direction) {
        setTimeout(function() {
          jQuery('.shareplus').shareplus('open');
        }, <?php echo $options['auto_open_delay_sec']; ?> * 1000);
	   }, {
  	   triggerOnce: true,
  	   offset: 'bottom-in-view'
  	 });
	<?php } elseif($auto_open == "time") { ?>
    	setTimeout(function() {
        jQuery('.shareplus').shareplus('open');
      }, <?php echo $options['auto_open_sec']; ?> * 1000);
  <?php } elseif($auto_open == "pageload") { // on window load ?>
      window.onload = jQuery('.shareplus').shareplus('open');
  <?php } ?>
});
</script>

<?php
}
add_action('wp_footer', 'shareplus_settings');


// ----------- add this for waypoint
function shareplus_scroll($content){
  $options = get_option('shareplus_options');
	if (is_single() || is_page() && $options['auto_open'] == "onvisible" || $options['auto_open'] == "onvisible_delay") {
		$content .= '<span id="shareplus_scroll"></span>';
	}
	return $content;
}
add_filter('the_content', 'shareplus_scroll', 0);



?>