<?php

/*

Plugin Name: Share+
Plugin URI: http://danielpaul.me/projects/share+/
Description: Share+ is a very powerful & highly customizable social sharing plugin which creates a new social sharing experience for your site users. Replace the long list of unusable sharing buttons with a neat, simple and organized sharing experience.
Version: 1.5
Author: Daniel Paul
Author URI: http://www.danielpaul.me/


====================================================================================================
||                                                                                                ||
||                               _____ __                                                         ||
||                              / ___// /_  ____ _________    __                                  ||
||                              \__ \/ __ \/ __ `/ ___/ _ \__/ /_                                 ||
||                             ___/ / / / / /_/ / /  /  __/_  __/                                 ||
||                            /____/_/ /_/\__,_/_/   \___/ /_/                                    ||
||                                                                                                ||
||                            by Daniel Paul [www.danielpaul.me]                                  ||
||                          */ define("plugin_version", "1.5"); /*                                ||
||                                                                                                ||
||                                                                                                ||
====================================================================================================


*/



// ------------------------------------------------------------------------
// REGISTER HOOKS & CALLBACK FUNCTIONS:
// ------------------------------------------------------------------------

// Set-up Action and Filter Hooks
register_activation_hook(__FILE__, 'shareplus_add_defaults');
register_uninstall_hook(__FILE__, 'shareplus_delete_plugin_options');

add_action('admin_init', 'shareplus_init' );
add_action('admin_menu', 'shareplus_add_options_page');
add_filter( 'plugin_action_links', 'shareplus_plugin_action_links', 10, 2 );



// --------------------------------------------------------------------------------------
// CALLBACK FUNCTION FOR: register_uninstall_hook(__FILE__, 'shareplus_delete_plugin_options')
// --------------------------------------------------------------------------------------

// Delete options table entries ONLY when plugin deactivated AND deleted
function shareplus_delete_plugin_options() {
	delete_option('shareplus_options');
}

// ------------------------------------------------------------------------------
// CALLBACK FUNCTION FOR: register_activation_hook(__FILE__, 'shareplus_add_defaults')
// ------------------------------------------------------------------------------

// Define default option settings
function shareplus_add_defaults() {
	$tmp = get_option('shareplus_options');
    if(($tmp['chk_default_options_db']=='1')||(!is_array($tmp))) {
		delete_option('shareplus_options');

		$arr = array(
		        "share_box_title" => "Share & Bookmark",
		        "theme_select" => "default",

		        "display_home" => "1",
		        "display_posts" => "1",
		        "display_pages" => "1",
		        "display_archives" => "1",

		        "facebook" => "1",
		        "twitter" => "1",
		        "google" => "1",
		        "digg" => "1",
		        "delicious" => "1",
		        "stumble" => "1",
		        "tumblr" => "1",
		        "linkedin" => "1",
		        "live" => "1",
		        "myspace" => "1",
		        "bebo" => "1",
		        "email" => "1",

		        "new_tab" => "yes",

		        "sticky_button" => "1",
		        "sticky_button_position" => "left",

		        "pin_button" => "1",
		        "gplus_button" => "1",

		        "tweet_button" => "1",
		        "tweet_via" => "",
		        "twitter_related" => "danielpaul94",

		        "fb_button" => "1",
		        "fb_action" => "like",
		        "fb_colour" => "light",

		        "auto_open" => "disable",
		        "auto_open_sec" => "300",
		        "auto_open_delay_sec" => "10",

		        "ga"  =>  "0",

						"chk_default_options_db" => ""
		);
		update_option('shareplus_options', $arr);
	}
}

// ------------------------------------------------------------------------------
// CALLBACK FUNCTION FOR: add_action('admin_init', 'shareplus_init' )
// ------------------------------------------------------------------------------

// Init plugin options to white list our options
function shareplus_init(){
	register_setting( 'shareplus_plugin_options', 'shareplus_options', 'shareplus_validate_options' );
}

// ------------------------------------------------------------------------------
// CALLBACK FUNCTION FOR: add_action('admin_menu', 'shareplus_add_options_page');
// ------------------------------------------------------------------------------

// Add menu page
function shareplus_add_options_page() {
	$page = add_options_page('Share+ Options Page', 'Share+', 'manage_options', __FILE__, 'shareplus_render_form');
	add_action( 'admin_print_styles-' . $page, 'shareplus_admin_css' );
}

// ------------------------------------------------------------------------------
// CALLBACK FUNCTION SPECIFIED IN: add_options_page()
// ------------------------------------------------------------------------------



// list of social sharing sites that share+ supports
$sites = array("facebook", "twitter", "google", "digg", "delicious", "stumble", "tumblr", "linkedin", "live", "myspace", "bebo", "email", "technorati", "yahoo", "newsvine", "reddit", "orkut", "evernote", "mixx", "netvibes", "friendfeed", "design_moo", "designfloat", "design_bump", "squidoo", "yahoo_buzz", "pinterest", "print", "favorites");


// load admin page css for share+ options page
function shareplus_admin_css() {
    wp_enqueue_style('shareplus-admin', plugins_url('css/admin.css', __FILE__), array(), "1.0");
}

// Render the Plugin options form
function shareplus_render_form() {
  require_once('inc/admin_options.php');
}

// Sanitize and validate input. Accepts an array, return a sanitized array.
function shareplus_validate_options($input) {
	 // strip html from textboxes
	 // Sanitize textbox input (strip html tags, and escape characters)
	$input['share_box_title'] =  wp_filter_nohtml_kses($input['share_box_title']);
	$input['tweet_via'] =  wp_filter_nohtml_kses($input['tweet_via']);
	$input['twitter_related'] =  wp_filter_nohtml_kses($input['twitter_related']);
	return $input;
}

// Display a Settings link on the main Plugins page
function shareplus_plugin_action_links( $links, $file ) {
	if ( $file == plugin_basename( __FILE__ ) ) {
		$shareplus_links = '<a href="'.get_admin_url().'options-general.php?page=shareplus/shareplus.php">'.__('Customise').'</a>';
		// make the 'Customise' link appear first
		array_unshift( $links, $shareplus_links );
	}
	return $links;
}

// Don't make WP look for Share+ updates in the WP plugin directory
add_filter('site_transient_update_plugins', 'shareplus_remove_update_nag');
function shareplus_remove_update_nag($value) {
 unset($value->response[ plugin_basename(__FILE__) ]);
 return $value;
}

require_once('inc/output.php');


/* ================================================== /





   ____                                 ___
  /\  _`\                    __        /\_ \
  \ \ \/\ \     __      ___ /\_\     __\//\ \
   \ \ \ \ \  /'__`\  /' _ `\/\ \  /'__`\\ \ \
    \ \ \_\ \/\ \L\.\_/\ \/\ \ \ \/\  __/ \_\ \_
     \ \____/\ \__/.\_\ \_\ \_\ \_\ \____\/\____\
      \/___/  \/__/\/_/\/_/\/_/\/_/\/____/\/____/


   ____                   ___
  /\  _`\                /\_ \
  \ \ \L\ \ __     __  __\//\ \      -=[ (c) 2013 Daniel Paul ]=-
   \ \ ,__/'__`\  /\ \/\ \ \ \ \
    \ \ \/\ \L\.\_\ \ \_\ \ \_\ \_     Do NOT duplicate or steal!
     \ \_\ \__/.\_\\ \____/ /\____\
      \/_/\/__/\/_/ \/___/  \/____/


  Hi there curious person! You are viewing the source code of my wordpress plugin.
  Hope you are not trying to steal anything ... :|

  Feel free to learn, analyze and/or use the techniques used in my plugin...

  * If you need any help modifying this plugin, please contact me via my codecanyon page.
  * I'll be happy to help... :)
  * http://codecanyon.net/users/DanielPaul?ref=DanielPaul





/ ================================================== */